summaryrefslogtreecommitdiff
path: root/include/drm/vmwgfx_drm.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/drm/vmwgfx_drm.h')
-rw-r--r--include/drm/vmwgfx_drm.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/drm/vmwgfx_drm.h b/include/drm/vmwgfx_drm.h
index 467b80c..c2b3909 100644
--- a/include/drm/vmwgfx_drm.h
+++ b/include/drm/vmwgfx_drm.h
@@ -289,7 +289,7 @@ union drm_vmw_surface_reference_arg {
* DRM_VMW_EXECBUF
*
* Submit a command buffer for execution on the host, and return a
* fence sequence that when signaled, indicates that the command buffer has
* executed.
*/
@@ -325,7 +325,7 @@ struct drm_vmw_execbuf_arg {
/**
* struct drm_vmw_fence_rep
*
* @fence_seq: Fence sequence associated with a command submission.
* @error: This member should've been set to -EFAULT on submission.
* The following actions should be take on completion:
* error == -EFAULT: Fence communication failed. The host is synchronized.
@@ -432,7 +432,7 @@ struct drm_vmw_unref_dmabuf_arg {
struct drm_vmw_fence_wait_arg {
- uint64_t sequence;
+ uint64_t seqno;
uint64_t kernel_cookie;
int32_t cookie_valid;
int32_t pad64;
@@ -289,7 +289,7 @@ union drm_vmw_surface_reference_arg {
*
* Submit a command buffer for execution on the host, and return a
- * fence sequence that when signaled, indicates that the command buffer has
+ * fence seqno that when signaled, indicates that the command buffer has
* executed.
*/
@@ -325,7 +325,7 @@ struct drm_vmw_execbuf_arg {
* struct drm_vmw_fence_rep
*
- * @fence_seq: Fence sequence associated with a command submission.
+ * @fence_seq: Fence seqno associated with a command submission.
* @error: This member should've been set to -EFAULT on submission.
* The following actions should be take on completion: